@@ -29,8 +29,14 @@ about_cb (GtkWidget *widget, gpointer data)
 	static GtkWidget *about = NULL;
 	gchar *authors[] = {
 		"George Lebl <jirka@5z.com>",
+		"Bastien Nocera <hadess@hadess.net> (fixes)",
 		NULL
 	};
+	gchar *documenters[] = {
+		NULL
+	};
+	/* Translator credits */
+	gchar *translator_credits = _("translator_credits");
 
 	if (about != NULL)
 	{
@@ -38,11 +44,13 @@ about_cb (GtkWidget *widget, gpointer data)
 		gdk_window_raise(about->window);
 		return;
 	}
-	about = gnome_about_new(_("The Gnome Calculator"), VERSION,
+	about = gnome_about_new(_("The GNOME Calculator"), VERSION,
 				"(C) 1998 the Free Software Foundation",
-				(const char **)authors,
 				_("Simple double precision calculator similiar "
 				  "to xcalc"),
+				(const char **)authors,
+				(const char **)documenters,
+				strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 				NULL);
 	gtk_signal_connect(GTK_OBJECT(about), "destroy",
 			   GTK_SIGNAL_FUNC(gtk_widget_destroyed), &about);
@@ -138,10 +146,12 @@ main(int argc, char *argv[])
 	static gint n_targets = sizeof(targets) / sizeof(targets[0]);
 	
 	/* Initialize the i18n stuff */
-	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
-	textdomain (PACKAGE);
+	bindtextdomain(GETTEXT_PACKAGE, GNOMELOCALEDIR);
+	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
+	textdomain(GETTEXT_PACKAGE);
 
-	gnome_init_with_popt_table ("gcalc", VERSION, argc, argv, options, 0, NULL);
+	gnome_program_init ("gcalc", VERSION, LIBGNOMEUI_MODULE,
+			argc, argv, GNOME_PARAM_POPT_TABLE, options, NULL);
 	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-calc2.png");
 
 	if (analog) {
@@ -149,7 +159,7 @@ main(int argc, char *argv[])
 		return 0;
 	}
 
-        app = gnome_app_new("gcalc", _("Gnome Calculator"));
+        app = gnome_app_new("gcalc", _("GNOME Calculator"));
 	gtk_window_set_wmclass (GTK_WINDOW (app), "gcalc", "gcalc");
 	gtk_window_set_policy (GTK_WINDOW (app), FALSE, TRUE, FALSE);
 
@@ -157,7 +167,7 @@ main(int argc, char *argv[])
 			GTK_SIGNAL_FUNC(quit_cb), NULL);
 
 	/*set up the menu*/
-        gnome_app_create_menus(GNOME_APP(app), gcalc_menu);
+        gnome_app_create_menus_with_data(GNOME_APP(app), gcalc_menu, app);
 
 	calc = gnome_calc_new();
 	gnome_calc_bind_extra_keys (GNOME_CALC (calc), GTK_WIDGET (app));
