@@ -1075,7 +1075,7 @@ static const CalculatorButton buttons[8][5] = {
 		{N_("tan"),  (GtkSignalFunc)simple_func, tan,    atan,   TRUE,  {'t','T',0}, N_("Tangent"), NULL },
 		{N_("DEG"),  (GtkSignalFunc)drg_toggle,  NULL,   NULL,   FALSE, {'d','D',0}, N_("Switch degrees / radians / grad"), NULL }
 	},{
-		{N_("e"),    (GtkSignalFunc)set_e,       NULL,   NULL,   FALSE, {'e','E',0}, NULL, NULL },
+		{N_("e"),    (GtkSignalFunc)set_e,       NULL,   NULL,   FALSE, {'e','E',0}, N_("Base of Natural Logarithm"), NULL },
 		{N_("EE"),   (GtkSignalFunc)add_digit,   "e+",   NULL,   FALSE, {0}, N_("Add digit"), NULL },
 		{N_("log"),  (GtkSignalFunc)simple_func, log10,  c_pow10,FALSE, {0}, N_("Base 10 Logarithm"), NULL },
 		{N_("ln"),   (GtkSignalFunc)simple_func, log,    c_powe, FALSE, {'l','L',0}, N_("Natural Logarithm"), NULL },
@@ -1153,7 +1153,7 @@ create_button(GnomeCalc *gc, GtkWidget *table, int x, int y)
 	}
 
 	if (but->tooltip != NULL) {
-		gtk_tooltips_set_tip(GTK_TOOLTIPS(gc->_priv->tooltips), w, but->tooltip, but->tooltip_private);
+		gtk_tooltips_set_tip(GTK_TOOLTIPS(gc->_priv->tooltips), w, _(but->tooltip), but->tooltip_private);
 	}
 
 	gtk_object_set_user_data(GTK_OBJECT(w),gc);
@@ -1174,6 +1174,7 @@ gnome_calc_instance_init (GnomeCalc *gc)
 {
 	gint x,y;
 	GtkWidget *table;
+	PangoFontDescription *pdesc;
 
 	gc->_priv = g_new0(GnomeCalcPrivate, 1);
 
@@ -1181,6 +1182,14 @@ gnome_calc_instance_init (GnomeCalc *gc)
 	gtk_editable_set_editable (GTK_EDITABLE (gc->_priv->text_display), FALSE);
 
 	gtk_box_pack_start (GTK_BOX (gc), gc->_priv->text_display, FALSE, FALSE, 0);
+	gtk_widget_set_direction (gc->_priv->text_display, GTK_TEXT_DIR_RTL);
+
+	pdesc = pango_font_description_from_string ("Helvetica 24");
+	if (pdesc != NULL) {
+		gtk_widget_modify_font (gc->_priv->text_display, pdesc);
+		pango_font_description_free (pdesc);
+	}
+
 	gtk_widget_show (gc->_priv->text_display);
 
 	gc->_priv->stack = NULL;
