@@ -59,14 +59,14 @@ create_chartable (void)
     {
         for (h = 0; h <= 23; h++)
         {
-	    char *s;
-	    int ch = v * 24 + h + 32;
-	    if (ch == 127)
-		    s = g_strdup (_("del"));
-	    else
-		    s = g_strdup_printf ("%c", (char)ch);
-
-            button = gtk_button_new_with_label (s);
+	    char buf[7];
+            int n;
+            int ch = v * 24 + h + 32;
+	   
+	    n = g_unichar_to_utf8 (ch, buf);
+            buf[n] = 0;
+            
+            button = gtk_button_new_with_label (buf);
             mainapp->buttons = g_list_append (mainapp->buttons, button);
             gtk_widget_set_style (GTK_BIN (button)->child, mainapp->btnstyle);
             gtk_table_attach (GTK_TABLE (chartable), button, h, h + 1, v, v + 1,
@@ -81,7 +81,6 @@ create_chartable (void)
             gtk_signal_connect (GTK_OBJECT (button), "leave",
               GTK_SIGNAL_FUNC (cb_charbtn_leave), NULL);
 
-            g_free (s);
         }
     }
 
@@ -89,15 +88,17 @@ create_chartable (void)
     {
         for (h = 0; h <= 23; h++)
         {
-	    char *s;
+            char buf[7];
+            int n;
 	    int ch = v * 24 + h + 161;
-
+	    
 	    if (ch > 0xff)
 		    continue;
 
-            s = g_strdup_printf ("%c", (char)ch);
-
-            button = gtk_button_new_with_label (s);
+            n = g_unichar_to_utf8 (ch, buf);
+            buf[n] = 0;
+	    
+            button = gtk_button_new_with_label (buf);
             mainapp->buttons = g_list_append (mainapp->buttons, button);
             gtk_widget_set_style (GTK_BIN (button)->child, mainapp->btnstyle);
             gtk_table_attach (GTK_TABLE (chartable), button,
@@ -113,13 +114,10 @@ create_chartable (void)
             gtk_signal_connect (GTK_OBJECT (button), "leave",
               GTK_SIGNAL_FUNC (cb_charbtn_leave), NULL);
 
-            g_free (s);
         }
     }
 
     gtk_widget_show_all (chartable);
-    gtk_widget_push_style (mainapp->btnstyle);
-    gtk_widget_pop_style ();
     return chartable;
 }
 
@@ -136,22 +134,24 @@ main_app_create_ui (MainApp *app)
 
     /* Main window */
     {
-        GnomeDockLayoutItem *item;
+        BonoboDockLayoutItem *item;
 
         app->window = gnome_app_new (_(PACKAGE), _("Gnome Character Map"));
         gtk_widget_set_name (app->window, "mainapp");
+        
         gtk_signal_connect_object (GTK_OBJECT (app->window), "destroy",
-          GTK_SIGNAL_FUNC (main_app_destroy), GTK_OBJECT (app));
+          GTK_SIGNAL_FUNC (main_app_destroy), G_OBJECT (app));
         gtk_widget_realize (app->window);
-
+	
         appbar = gnome_appbar_new (FALSE, TRUE, GNOME_PREFERENCES_USER);
         gnome_app_set_statusbar (GNOME_APP (app->window), appbar);
         gtk_widget_show (appbar);
 
         gnome_app_create_menus (GNOME_APP (app->window), menubar);
         gnome_app_install_menu_hints (GNOME_APP (app->window), menubar);
-
+#ifdef GO_AWAY
         gnome_app_create_toolbar (GNOME_APP (app->window), toolbar);
+#endif
         item = g_list_nth_data (GNOME_APP (app->window)->layout->items, 0);
         app->actionbar = GTK_WIDGET (item->item);
     }
@@ -163,14 +163,14 @@ main_app_create_ui (MainApp *app)
       app->window)->contents), 8);
 
     {
-        GnomeDockLayoutItem *item;
+        BonoboDockLayoutItem *item;
 
         hbox = gtk_hbox_new (FALSE, 6);
         gtk_container_set_border_width (GTK_CONTAINER (hbox), 1);
         gnome_app_add_docked (GNOME_APP (app->window), hbox, _("Action Toolbar"),
-          GNOME_DOCK_ITEM_BEH_EXCLUSIVE | GNOME_DOCK_ITEM_BEH_NEVER_VERTICAL,
-          GNOME_DOCK_TOP, 2, 0, 1);
-
+          BONOBO_DOCK_ITEM_BEH_EXCLUSIVE | BONOBO_DOCK_ITEM_BEH_NEVER_VERTICAL,
+          BONOBO_DOCK_TOP, 2, 0, 1);
+#ifdef GO_AWAY
         app->fontpicker = gnome_font_picker_new ();
         gnome_font_picker_set_mode (GNOME_FONT_PICKER (app->fontpicker),
           GNOME_FONT_PICKER_MODE_FONT_INFO);
@@ -185,14 +185,19 @@ main_app_create_ui (MainApp *app)
 
         vsep = gtk_vseparator_new ();
         gtk_box_pack_start (GTK_BOX (hbox), vsep, FALSE, FALSE, 0);
-
-        alabel = gtk_label_new (_("Text to copy:"));
+#endif	
+        alabel = gtk_label_new_with_mnemonic (_("_Text to copy:"));
         gtk_box_pack_start (GTK_BOX (hbox), alabel, FALSE, TRUE, 0);
 
         app->entry = gtk_entry_new ();
+        gtk_label_set_mnemonic_widget (GTK_LABEL (alabel), app->entry);
         gtk_box_pack_start (GTK_BOX (hbox), app->entry, TRUE, TRUE, 0);
-        gnome_popup_menu_attach (gnome_popup_menu_new (edit_menu),
-          app->entry, NULL);
+        
+        button = gtk_button_new_with_mnemonic (_("_Copy"));
+        gtk_container_set_border_width (GTK_CONTAINER (button), 2);
+        g_signal_connect (G_OBJECT (button), "clicked",
+        		  G_CALLBACK (cb_copy_click), NULL);
+        gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);		  
 
         gtk_widget_show_all (hbox);
         item = g_list_nth_data (GNOME_APP (app->window)->layout->items, 0);
@@ -211,11 +216,13 @@ main_app_create_ui (MainApp *app)
         tmp = gtk_button_new ();
         gtk_widget_ensure_style(tmp);
         app->btnstyle = gtk_style_copy (gtk_widget_get_style (tmp));
+#ifdef THIS_SOULHD_GO_AWAY       
         font = gdk_fontset_load (
           _("-*-helvetica-medium-r-normal-*-12-*-*-*-p-*-*-*,*-r-*")
         );
 	if (font != NULL)
-		app->btnstyle->font = font;
+		gtk_style_set_font(app->btnstyle, font);
+#endif
         gtk_widget_destroy (tmp);
 
         chartable = create_chartable ();
@@ -226,7 +233,7 @@ main_app_create_ui (MainApp *app)
     vbox2 = gtk_vbox_new (FALSE, 0);
     gtk_box_pack_start (GTK_BOX (hbox2), vbox2, FALSE, TRUE, 0);
 
-
+#ifdef GO_AWAY
     /* The buttonbox */
     {
         buttonbox = gtk_vbutton_box_new ();
@@ -264,7 +271,7 @@ main_app_create_ui (MainApp *app)
           _("-*-helvetica-bold-r-normal-*-*-180-*-*-p-*-*-*,*-r-*")
         );
 	if (font != NULL)
-		style->font = font;
+		gtk_style_set_font(style, font);
 
         gtk_widget_set_style (viewport, style);
         gtk_box_pack_start (GTK_BOX (vbox2), viewport, FALSE, TRUE, 0);
@@ -272,20 +279,15 @@ main_app_create_ui (MainApp *app)
         app->preview_label = gtk_label_new (NULL);
         gtk_container_add (GTK_CONTAINER (viewport), app->preview_label);
         gtk_widget_set_style (app->preview_label, style);
-
-        gtk_widget_push_style (style);
-        gtk_widget_pop_style ();
     }
-
+#endif
     gtk_widget_show_all (vbox);
     gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (
       view_menu[0].widget), TRUE);
     gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (
       view_menu[1].widget), TRUE);
     gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (
-      view_menu[2].widget), TRUE);
-    gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (
-      settings_menu[3].widget), TRUE);
+      settings_menu[1].widget), TRUE);
     gtk_widget_grab_focus (app->entry);
 }
 
@@ -297,24 +299,34 @@ main_app_init (MainApp *obj)
     main_app_create_ui (obj);
 }
 
+static void
+main_app_class_init (MainAppClass *klass)
+{
+    GObjectClass *object_class = G_OBJECT_CLASS (klass);
+    
+}
 
-guint
+GType
 main_app_get_type (void)
 {
-    static guint ga_type = 0;
+    static GType ga_type = 0;
 
+    g_type_init ();
+    
     if (!ga_type) {
-        GtkTypeInfo ga_info = {
-          "MainApp",
-          sizeof (MainApp),
+        static const GTypeInfo ga_info = {
           sizeof (MainAppClass),
-          (GtkClassInitFunc) NULL,
-          (GtkObjectInitFunc) main_app_init,
-          (GtkArgSetFunc) NULL,
-          (GtkArgGetFunc) NULL,
-          (GtkClassInitFunc) NULL
+          (GBaseInitFunc) NULL,
+          (GBaseFinalizeFunc) NULL,
+          (GClassInitFunc) main_app_class_init,
+          NULL,
+          NULL,
+          sizeof (MainApp),
+          0,
+          (GInstanceInitFunc) main_app_init,
         };
-        ga_type = gtk_type_unique (gtk_object_get_type (), &ga_info);
+        ga_type = g_type_register_static (G_TYPE_OBJECT, "MainApp",
+        				  &ga_info, 0);
     }
     return ga_type;
 }
@@ -323,7 +335,7 @@ main_app_get_type (void)
 MainApp *
 main_app_new (void)
 {
-    return MAIN_APP (gtk_type_new ((GtkType) MAIN_APP_TYPE));
+    return MAIN_APP (g_object_new (MAIN_APP_TYPE, NULL));
 }
 
 
@@ -333,9 +345,6 @@ main_app_destroy (MainApp *obj)
     g_return_if_fail (obj != NULL);
     g_return_if_fail (MAIN_IS_APP (obj) == TRUE);
 
-    if (obj->window != NULL) gtk_widget_destroy (obj->window);
-    if (obj->btnstyle != NULL) g_free (obj->btnstyle);
-    gtk_object_destroy (GTK_OBJECT (obj));
     gtk_main_quit ();
 }
 
