@@ -71,7 +71,7 @@ typedef struct __menu_item MenuItem;
 typedef struct
 {
   /* Fonts ----------------------------------------------------- */
-   PangoFontDescription *heading, *headingb, *fixed, *fixedb, *small;
+  GdkFont *heading, *headingb, *fixed, *fixedb, *small;
 
   /* Colors ---------------------------------------------------- */
   GdkColor black, green, blue, blue1, blue3, gray25, gray50;
@@ -206,7 +206,7 @@ typedef struct
   CalendarData *caldata;
 
   /* Monitor info */
-  GtkWidget *mon_lines;
+  GtkCList *mon_lines;
   MonActions alert;
   long offset_end;
   int mon_on;		/* Flag set if we are monitoring this log          */
